@@ -1,9 +1,8 @@
 ## ----setup, include=FALSE-----------------------------------------------------
-knitr::opts_chunk$set(echo = TRUE)
-knitr::opts_chunk$set(collapse = TRUE)
+knitr::opts_chunk$set(echo = TRUE, collapse = TRUE, dev = "png")
+ev = suppressWarnings(require(starsdata, quietly = TRUE))
 knitr::opts_chunk$set(fig.height = 4.5)
 knitr::opts_chunk$set(fig.width = 6)
-ev = suppressWarnings(require(starsdata, quietly = TRUE))
 
 ## -----------------------------------------------------------------------------
 library(stars)
@@ -20,8 +19,8 @@ plot(x, axes = TRUE)
 x
 
 ## ----eval=ev------------------------------------------------------------------
-#  library(cubelyr)
-#  as.tbl_cube(x)
+library(cubelyr)
+as.tbl_cube(x)
 
 ## -----------------------------------------------------------------------------
 (x.spl = split(x, "band"))
@@ -47,68 +46,68 @@ circle = st_sfc(st_buffer(st_point(c(293749.5, 9115745)), 400), crs = st_crs(x))
 plot(x[circle][, , , 1], reset = FALSE)
 plot(circle, col = NA, border = 'red', add = TRUE, lwd = 2)
 
-## ----eval=FALSE---------------------------------------------------------------
-#  x1 = read_stars(tif, options = c("OVERVIEW_LEVEL=1"))
-#  x2 = read_stars(tif, options = c("OVERVIEW_LEVEL=2"))
-#  x3 = read_stars(tif, options = c("OVERVIEW_LEVEL=3"))
-#  dim(x1)
-#  dim(x2)
-#  dim(x3)
-#  par(mfrow = c(1, 3), mar = rep(0.2, 4))
-#  image(x1[,,,1])
-#  image(x2[,,,1])
-#  image(x3[,,,1])
+## -----------------------------------------------------------------------------
+x1 = read_stars(tif, options = c("OVERVIEW_LEVEL=1"))
+x2 = read_stars(tif, options = c("OVERVIEW_LEVEL=2"))
+x3 = read_stars(tif, options = c("OVERVIEW_LEVEL=3"))
+dim(x1)
+dim(x2)
+dim(x3)
+par(mfrow = c(1, 3), mar = rep(0.2, 4))
+image(x1[,,,1])
+image(x2[,,,1])
+image(x3[,,,1])
 
 ## ----eval=ev------------------------------------------------------------------
-#  system.file("nc/bcsd_obs_1999.nc", package = "stars") |>
-#  	read_stars() -> w
+system.file("nc/bcsd_obs_1999.nc", package = "stars") |>
+	read_stars() -> w
 
 ## ----eval=ev------------------------------------------------------------------
-#  w
+w
 
 ## -----------------------------------------------------------------------------
 system.file("nc/bcsd_obs_1999.nc", package = "stars") |>
     read_ncdf()
 
 ## ----eval=ev------------------------------------------------------------------
-#  x = c(
-#  "avhrr-only-v2.19810901.nc",
-#  "avhrr-only-v2.19810902.nc",
-#  "avhrr-only-v2.19810903.nc",
-#  "avhrr-only-v2.19810904.nc",
-#  "avhrr-only-v2.19810905.nc",
-#  "avhrr-only-v2.19810906.nc",
-#  "avhrr-only-v2.19810907.nc",
-#  "avhrr-only-v2.19810908.nc",
-#  "avhrr-only-v2.19810909.nc"
-#  )
-#  # see the second vignette:
-#  # install.packages("starsdata", repos = "http://pebesma.staff.ifgi.de", type = "source")
-#  file_list = system.file(paste0("netcdf/", x), package = "starsdata")
-#  (y = read_stars(file_list, quiet = TRUE))
+x = c(
+"avhrr-only-v2.19810901.nc",
+"avhrr-only-v2.19810902.nc",
+"avhrr-only-v2.19810903.nc",
+"avhrr-only-v2.19810904.nc",
+"avhrr-only-v2.19810905.nc",
+"avhrr-only-v2.19810906.nc",
+"avhrr-only-v2.19810907.nc",
+"avhrr-only-v2.19810908.nc",
+"avhrr-only-v2.19810909.nc"
+)
+# see the second vignette:
+# install.packages("starsdata", repos = "http://pebesma.staff.ifgi.de", type = "source")
+file_list = system.file(paste0("netcdf/", x), package = "starsdata")
+(y = read_stars(file_list, quiet = TRUE))
 
 ## ----eval=ev------------------------------------------------------------------
-#  library(dplyr)
-#  library(abind)
-#  z <- y |> select(sst) |> adrop()
+library(dplyr)
+library(abind)
+z <- y |> select(sst) |> adrop()
 
 ## ----eval=ev------------------------------------------------------------------
-#  # convert POSIXct time to character, to please ggplot's facet_wrap()
-#  z1 = st_set_dimensions(z, 3, values = as.character(st_get_dimension_values(z, 3)))
-#  library(ggplot2)
-#  library(viridis)
-#  library(ggthemes)
-#  ggplot() +
-#    geom_stars(data = z1[1], alpha = 0.8, downsample = c(10, 10, 1)) +
-#    facet_wrap("time") +
-#    scale_fill_viridis() +
-#    coord_equal() +
-#    theme_map() +
-#    theme(legend.position = "bottom") +
-#    theme(legend.key.width = unit(2, "cm"))
+# convert POSIXct time to character, to please ggplot's facet_wrap()
+z1 = st_set_dimensions(z, 3, values = as.character(st_get_dimension_values(z, 3)))
+library(ggplot2)
+library(viridis)
+library(ggthemes)
+ggplot() +  
+  geom_stars(data = z1[1], alpha = 0.8, downsample = c(10, 10, 1)) + 
+  facet_wrap("time") +
+  scale_fill_viridis() +
+  coord_equal() +
+  theme_map() +
+  theme(legend.position = "bottom") +
+  theme(legend.key.width = unit(2, "cm"))
 
 ## ----eval=ev------------------------------------------------------------------
-#  write_stars(adrop(y[1]), "sst.tif")
+write_stars(adrop(y[1]), "sst.tif")
 
 ## -----------------------------------------------------------------------------
 prec_file = system.file("nc/test_stageiv_xyt.nc", package = "stars")
@@ -145,19 +144,19 @@ dims = st_dimensions(origin = from, destination = to, mode = mode, day = day, ho
 traffic = array(rpois(prod(n), 10), dim = n) # simulated traffic counts
 (st = st_as_stars(list(traffic = traffic),  dimensions = dims))
 
-## ----eval=FALSE---------------------------------------------------------------
-#  st |> as.tbl_cube()
+## ----eval=ev------------------------------------------------------------------
+st |> as.tbl_cube()
 
-## ----eval=FALSE---------------------------------------------------------------
-#  b <- st |>
-#    as.tbl_cube() |>
-#    filter(mode == "bike") |>
-#    group_by(hour) |>
-#    summarise(traffic = mean(traffic)) |>
-#    as.data.frame()
-#  require(ggforce) # for plotting a units variable
-#  ggplot() +
-#    geom_line(data = b, aes(x = hour, y = traffic))
+## ----eval=ev------------------------------------------------------------------
+b <- st |> 
+  as.tbl_cube() |> 
+  filter(mode == "bike") |> 
+  group_by(hour) |>
+  summarise(traffic = mean(traffic)) |> 
+  as.data.frame()
+require(ggforce) # for plotting a units variable
+ggplot() +  
+  geom_line(data = b, aes(x = hour, y = traffic))
 
 ## -----------------------------------------------------------------------------
 s = system.file("tif/lc.tif", package = "stars")
