@@ -1,7 +1,7 @@
 options(rgdal_show_exportToProj4_warnings = "none")
 suppressPackageStartupMessages(library(stars))
 
-if (require("raster", quietly = TRUE) && 
+if (suppressPackageStartupMessages(require(sp, quietly = TRUE)) && require("raster", quietly = TRUE) && 
 	suppressPackageStartupMessages(require("terra", quietly = TRUE))) {
 
 tif = system.file("tif/L7_ETMs.tif", package = "stars")
